SystemOrganization addCategory: #'Pier-FuelPersistence-Test'!

TestCase subclass: #PRFuelPersistencyTest
	instanceVariableNames: 'kernel directory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-FuelPersistence-Test'!

!PRFuelPersistencyTest methodsFor: 'running' stamp: 'YanniChiu 5/31/2011 23:40'!
kernelName
	^ 'fuelpersistency'! !

!PRFuelPersistencyTest methodsFor: 'running' stamp: 'YanniChiu 6/13/2011 00:22'!
setUp
	| persistency |
	directory := FSFilesystem inMemory working.
	persistency := PRFuelPersistency new directory: directory; namePrefix: self snapshotNamePrefix; yourself.
	kernel := PRKernel
		named: self kernelName
		root: ((PRPage named: 'root') contents: 'root content'; yourself).
	kernel persistency: persistency.
! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:39'!
setUpBasic
	kernel root addChild: ((PRPage named: 'page1') contents: 'page1 contents'; yourself).
! !

!PRFuelPersistencyTest methodsFor: 'running' stamp: 'YanniChiu 5/31/2011 23:40'!
snapshotNamePrefix
	^ 'test_fuel_'! !

!PRFuelPersistencyTest methodsFor: 'running' stamp: 'YanniChiu 5/31/2011 23:39'!
tearDown

	kernel notNil
		ifTrue: [ PRKernel instances remove: kernel ].! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:39'!
testCleanupBackupImages
	| p dateAndTime name |

	dateAndTime := DateAndTime now.
	p := kernel persistency.
	p maxImages: 2.
	name := p snapshotNameFromDateAndTime: dateAndTime.
	"Must set directory prior to call, else default from filesystem is used"
	p directory: directory; snapshotWithName: name.
	p directory: directory; cleanupBackupImages.
	self assert: directory entries size = 1.

	name := p snapshotNameFromDateAndTime: dateAndTime + (Duration seconds: 1).
	p directory: directory; snapshotWithName: name.
	p directory: directory; cleanupBackupImages.
	self assert: directory entries size = 2.

	name := p snapshotNameFromDateAndTime: dateAndTime + (Duration seconds: 2).
	p directory: directory; snapshotWithName: name.
	p directory: directory; cleanupBackupImages.
	self assert: directory entries size = 2.
	self assert: (directory entries detect: [:e | e basename = name] ifNone: [nil]) notNil.
! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:41'!
testDefaultDirectoryName
	| saveValue p |

	[
		saveValue := PRFuelPersistency defaultDirectoryName.
		PRFuelPersistency defaultDirectoryName: '/foo/bar/abc'.
		"MADescriptionBuilder default flush."
		p := PRFuelPersistency new.
		self assert: p directoryName = '/foo/bar/abc'.
	]
	ensure: [
		PRFuelPersistency defaultDirectoryName: saveValue.
	]! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:39'!
testDefaultNamePrefix
	| p |

	p := kernel persistency.
	p namePrefix: nil.
	self assert: p namePrefix = (self kernelName, '_').
! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:42'!
testImportNewestSnapshot
	| dateAndTime k1 k2 p2 |

	self setUpBasic.

	dateAndTime := DateAndTime now.
	kernel persistency snapshotWithName: (kernel persistency snapshotNameFromDateAndTime: dateAndTime).

	k1 := PRFuelPersistency importFromDirectoryReference: directory withPrefix: self snapshotNamePrefix.
	self verifyBasic: kernel with: k1.

	k1 root addChild: ((PRPage named: 'page2') contents: 'page2 contents'; yourself).
	k1 persistency directory: directory.
	k1 persistency snapshotWithName: (k1 persistency snapshotNameFromDateAndTime: dateAndTime + (Duration seconds: 1)).
	k2 := PRFuelPersistency importFromDirectoryReference: directory withPrefix: self snapshotNamePrefix.

	self verifyBasic: k1 with: k2.
	p2 := k2 root lookupPath: 'page2'.
	self assert: p2 notNil.
	self assert: p2 name = 'page2'.
	self assert: p2 contents = 'page2 contents'.
! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:42'!
testSnapshot
	| newKernel |

	self setUpBasic.

	"Be careful to sanitize the kernel. The dataStore was moved to PRContext,
	when having it in kernel caused a problem with deserialization."
	"kernel propertyAt: #dataStore put: JRPersistence current."

	kernel persistency snapshot.

	newKernel := PRFuelPersistency importFromDirectoryReference: directory withPrefix: self snapshotNamePrefix.

	self verifyBasic: kernel with: newKernel.
! !

!PRFuelPersistencyTest methodsFor: 'testing' stamp: 'YanniChiu 5/31/2011 23:42'!
verifyBasic: oldKernel with: newKernel
	| newRoot newPage1 |

	self assert: newKernel name = oldKernel name.
	self assert: newKernel name = 'fuelpersistency'.

	newRoot := newKernel root.
	self assert: newRoot notNil.
	self assert: newRoot name = 'root'.
	self assert: newRoot contents = 'root content'.

	newPage1 := newRoot lookupPath: 'page1'.
	self assert: newPage1 notNil.
	self assert: newPage1 name = 'page1'.
	self assert: newPage1 contents = 'page1 contents'.
! !
